summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSebastian Dröge <sebastian.droege@collabora.co.uk>2010-12-19 11:17:47 +0100
committerSebastian Dröge <sebastian.droege@collabora.co.uk>2010-12-19 11:21:27 +0100
commit1ec5ffbfc9dc5483e5de04a85cf4372a5c2e89dc (patch)
treea8e5223ef2433b5b92fef878bccd36e52de3e60d
parent369f41913cce96658d7a0f26e02f58200ef40af3 (diff)
autovideoconvert: Rename and adjust unit test too
-rw-r--r--Makefile.am1
-rw-r--r--tests/check/Makefile.am2
-rw-r--r--tests/check/elements/.gitignore1
-rw-r--r--tests/check/elements/autovideoconvert.c (renamed from tests/check/elements/autocolorspace.c)20
4 files changed, 13 insertions, 11 deletions
diff --git a/Makefile.am b/Makefile.am
index 37b104d17e..93388d7927 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -52,6 +52,7 @@ CRUFT_FILES = \
$(top_builddir)/gst/shapewipe/.libs/*.{so,dll,DLL,dylib} \
$(top_builddir)/gst/imagefreeze/.libs/*.{so,dll,DLL,dylib} \
$(top_builddir)/sys/oss4/.libs/*.{so,dll,DLL,dylib} \
+ $(top_builddir)/tests/check/elements/autocolorspace \
$(top_builddir)/tests/check/elements/capssetter \
$(top_builddir)/tests/check/elements/imagefreeze \
$(top_builddir)/tests/check/pipelines/metadata \
diff --git a/tests/check/Makefile.am b/tests/check/Makefile.am
index 81c5862e9c..1b698a3ae8 100644
--- a/tests/check/Makefile.am
+++ b/tests/check/Makefile.am
@@ -152,7 +152,7 @@ check_PROGRAMS = \
elements/ac3parse \
elements/amrparse \
elements/autoconvert \
- elements/autocolorspace \
+ elements/autovideoconvert \
elements/asfmux \
elements/camerabin \
elements/dataurisrc \
diff --git a/tests/check/elements/.gitignore b/tests/check/elements/.gitignore
index 175b0bea08..95eaceba02 100644
--- a/tests/check/elements/.gitignore
+++ b/tests/check/elements/.gitignore
@@ -5,6 +5,7 @@ amrparse
asfmux
assrender
autoconvert
+autovideoconvert
camerabin
deinterleave
dataurisrc
diff --git a/tests/check/elements/autocolorspace.c b/tests/check/elements/autovideoconvert.c
index 51371f3b5e..c4e9e51055 100644
--- a/tests/check/elements/autocolorspace.c
+++ b/tests/check/elements/autovideoconvert.c
@@ -1,6 +1,6 @@
/* GStreamer
*
* unit test for autocolorspace element
* Copyright (C) 2009 Jan Schmidt <thaytan@noraisin.net>
* Copyright (C) 2010 ST-Ericsson SA
* @author: Benjamin Gaignard <benjamin.gaignard@stericsson.com>
@@ -95,13 +95,13 @@ run_test (const gchar * pipeline_string)
}
-GST_START_TEST (test_autocolorspace_rbg2bayer)
+GST_START_TEST (test_autovideoconvert_rbg2bayer)
{
gchar *pipeline;
pipeline =
g_strdup_printf
- ("videotestsrc num-buffers=1 ! video/x-raw-rgb,bpp=32,depth=32,width=100,height=100,framerate=10/1 ! autocolorspace ! video/x-raw-bayer,width=100,height=100,format=bggr,framerate=10/1 ! fakesink");
+ ("videotestsrc num-buffers=1 ! video/x-raw-rgb,bpp=32,depth=32,width=100,height=100,framerate=10/1 ! autovideoconvert ! video/x-raw-bayer,width=100,height=100,format=bggr,framerate=10/1 ! fakesink");
run_test (pipeline);
g_free (pipeline);
@@ -109,13 +109,13 @@ GST_START_TEST (test_autocolorspace_rbg2bayer)
GST_END_TEST;
-GST_START_TEST (test_autocolorspace_ffmpegcolorspace)
+GST_START_TEST (test_autovideoconvert_ffmpegcolorspace)
{
gchar *pipeline;
pipeline =
g_strdup_printf
- ("videotestsrc num-buffers=1 ! video/x-raw-rgb,bpp=32,width=100,height=100,framerate=10/1 ! autocolorspace ! video/x-raw-rgb,bpp=16,width=100,height=100,framerate=10/1 ! fakesink");
+ ("videotestsrc num-buffers=1 ! video/x-raw-rgb,bpp=32,width=100,height=100,framerate=10/1 ! autovideoconvert ! video/x-raw-rgb,bpp=16,width=100,height=100,framerate=10/1 ! fakesink");
run_test (pipeline);
g_free (pipeline);
@@ -124,16 +124,16 @@ GST_START_TEST (test_autocolorspace_ffmpegcolorspace)
GST_END_TEST;
static Suite *
-autocolorspace_suite (void)
+autovideoconvert_suite (void)
{
- Suite *s = suite_create ("autocolorspace");
+ Suite *s = suite_create ("autovideoconvert");
TCase *tc_basic = tcase_create ("general");
suite_add_tcase (s, tc_basic);
- tcase_add_test (tc_basic, test_autocolorspace_rbg2bayer);
- tcase_add_test (tc_basic, test_autocolorspace_ffmpegcolorspace);
+ tcase_add_test (tc_basic, test_autovideoconvert_rbg2bayer);
+ tcase_add_test (tc_basic, test_autovideoconvert_ffmpegcolorspace);
return s;
}
-GST_CHECK_MAIN (autocolorspace);
+GST_CHECK_MAIN (autovideoconvert);
@@ -1,6 +1,6 @@
/* GStreamer
*
- * unit test for autocolorspace element
+ * unit test for autovideoconvert element
* Copyright (C) 2009 Jan Schmidt <thaytan@noraisin.net>
* Copyright (C) 2010 ST-Ericsson SA